@@ -41,22 +41,6 @@ void Controller::toggleState() {
 }
 
 QString Controller::getLanguage() const {
-    QMap<QString, QString> langs;
-
-    QString english(tr("English"));
-    QString german(tr("German"));
-    QString italian(tr("Italian"));
-    QString finnish(tr("Finnish"));
-    QString dutch(tr("Dutch"));
-    QString polish(tr("Polish"));
-
-    langs[english] = "en";
-    langs[german] = "de";
-    langs[italian] = "it";
-    langs[finnish] = "fi";
-    langs[dutch] = "nl";
-    langs[polish] = "pl";
-
     QString langCode = "en";
 
     QSqlDatabase db;
@@ -66,13 +50,10 @@ QString Controller::getLanguage() const {
 
     QSqlQuery query("select value from settings where setting = 'language'");
     QSqlRecord record = query.record();
-    QString language;
     if (record.count() > 0) {
         while (query.next()) {
-            language = query.value(0).toString();
+            langCode = query.value(0).toString();
         }
-        //        qDebug() << language;
-        langCode = langs.value(language, "en");
     }
     //    qDebug() << langCode;
     db.close();
@@ -80,13 +61,13 @@ QString Controller::getLanguage() const {
 }
 
 void Controller::setOrientation(const QString &orient) {
-    if (orient == "Automatic") {
+    if (orient == "automatic") {
         m_view->setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
     }
-    else if (orient == "Landscape") {
+    else if (orient == "landscape") {
         m_view->setOrientation(QmlApplicationViewer::ScreenOrientationLockLandscape);
     }
-    else if (orient == "Portrait") {
+    else if (orient == "portrait") {
         m_view->setOrientation(QmlApplicationViewer::ScreenOrientationLockPortrait);
     }
 }
@@ -123,6 +104,30 @@ void Controller::getMediaPlayerFromDB() {
     db.close();
 }
 
+QStringList Controller::getProxyFromDB() const {
+    QSqlDatabase db;
+    db = QSqlDatabase::addDatabase("QSQLITE");
+    db.setDatabaseName("/home/user/.config/cutetube/Databases/63db502ea46fc7fe74e01e615d2c00d6.sqlite");
+    db.open();
+
+    QSqlQuery query("select value from settings where setting = 'proxy'");
+    QSqlRecord record = query.record();
+    QStringList proxy;
+    QString result;
+    if (record.count() > 0) {
+        while (query.next()) {
+            result = query.value(0).toString();
+            proxy = result.split(":");
+        }
+        //        qDebug() << proxy;
+    }
+    else {
+        proxy << "" << "";
+    }
+    db.close();
+    return proxy;
+}
+
 QStringList Controller::getInstalledMediaPlayers() const {
     QStringList playerList;
     playerList << "Media Player";
@@ -160,15 +165,14 @@ void Controller::playVideo(const QString &url) {
         dbus_iface.call("mime_open", url);
     }
     emit playbackStarted();
-#endif
 
-//#ifdef Q_WS_X11
-//    QStringList args;
-//    args << "-cache" << "4096" << "-fs" << url;
-//    QProcess *player = new QProcess();
-//    connect(player, SIGNAL(finished(int, QProcess::ExitStatus)), player, SLOT(deleteLater()));
-//    player->start("/usr/bin/mplayer", args);
-//#endif
+#else
+    QStringList args;
+    args << "-cache" << "4096" << "-fs" << url;
+    QProcess *player = new QProcess();
+    connect(player, SIGNAL(finished(int, QProcess::ExitStatus)), player, SLOT(deleteLater()));
+    player->start("/usr/bin/mplayer", args);
+#endif
 }
 
 void Controller::deleteVideo(const QString &path) {
@@ -185,7 +189,7 @@ void Controller::deleteVideo(const QString &path) {
     }
 }
 
-QString Controller::archiveFileExists(const QString &filePath, const QString &archivePath) {
+QString Controller::archiveFileExists(const QString &filePath, const QString &archivePath) const {
     QString result = "Not found";
     if (QFile::exists(filePath)) {
         result = "Unchanged";
