@@ -5,7 +5,7 @@
     <name>AboutDialog</name>
     <message>
         <location filename="../AboutDialog.qml" line="44"/>
-        <source>cuteTube-QML - 0.6.1</source>
+        <source>cuteTube-QML - 0.6.3</source>
         <translation></translation>
     </message>
     <message>
@@ -167,42 +167,52 @@
 <context>
     <name>Controller</name>
     <message>
-        <location filename="../../../controller.cpp" line="45"/>
+        <location filename="../../../controller.cpp" line="46"/>
         <source>English</source>
         <translation>Inglese</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="46"/>
+        <location filename="../../../controller.cpp" line="47"/>
         <source>German</source>
         <translation>Tedesco</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="47"/>
+        <location filename="../../../controller.cpp" line="48"/>
         <source>Italian</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="48"/>
+        <location filename="../../../controller.cpp" line="49"/>
         <source>Finnish</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="168"/>
+        <location filename="../../../controller.cpp" line="50"/>
+        <source>Dutch</source>
+        <translation>Olandese</translation>
+    </message>
+    <message>
+        <location filename="../../../controller.cpp" line="51"/>
+        <source>Polish</source>
+        <translation>Polacco</translation>
+    </message>
+    <message>
+        <location filename="../../../controller.cpp" line="177"/>
         <source>Video deleted from device</source>
         <translation>Video cancellato dal dispositivo</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="171"/>
+        <location filename="../../../controller.cpp" line="180"/>
         <source>Unable to delete video</source>
         <translation>Impossibile cancellare il video</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="175"/>
+        <location filename="../../../controller.cpp" line="184"/>
         <source>Video not found</source>
         <translation>Video non trovato</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="230"/>
+        <location filename="../../../controller.cpp" line="239"/>
         <source>Copied to clipboard</source>
         <translation>Copiato negli appunti</translation>
     </message>
@@ -545,27 +555,27 @@
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="19"/>
-        <location filename="../SettingsDialog.qml" line="38"/>
-        <location filename="../SettingsDialog.qml" line="71"/>
+        <location filename="../SettingsDialog.qml" line="39"/>
+        <location filename="../SettingsDialog.qml" line="72"/>
         <source>Automatically</source>
         <translation>Automaticamente</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="19"/>
-        <location filename="../SettingsDialog.qml" line="41"/>
+        <location filename="../SettingsDialog.qml" line="42"/>
         <source>Manually</source>
         <translation>Manualmente</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="20"/>
-        <location filename="../SettingsDialog.qml" line="45"/>
-        <location filename="../SettingsDialog.qml" line="77"/>
+        <location filename="../SettingsDialog.qml" line="46"/>
+        <location filename="../SettingsDialog.qml" line="78"/>
         <source>On</source>
         <translation>Attiva</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="20"/>
-        <location filename="../SettingsDialog.qml" line="48"/>
+        <location filename="../SettingsDialog.qml" line="49"/>
         <source>Off</source>
         <translation>Disattiva</translation>
     </message>
@@ -585,8 +595,7 @@
         <translation>Verticale</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="22"/>
-        <location filename="../SettingsDialog.qml" line="128"/>
+        <location filename="../SettingsDialog.qml" line="129"/>
         <location filename="../SettingsDialog.qml" line="430"/>
         <source>Media Player</source>
         <translation></translation>
@@ -622,89 +631,99 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="37"/>
-        <location filename="../SettingsDialog.qml" line="72"/>
+        <location filename="../SettingsDialog.qml" line="24"/>
+        <source>Dutch</source>
+        <translation>Olandese</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="24"/>
+        <source>Polish</source>
+        <translation>Polacco</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="38"/>
+        <location filename="../SettingsDialog.qml" line="73"/>
         <source>Queued</source>
         <translation>In Coda</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="75"/>
+        <location filename="../SettingsDialog.qml" line="76"/>
         <source>Paused</source>
         <translation>In Pausa</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="84"/>
+        <location filename="../SettingsDialog.qml" line="85"/>
         <source>Your settings have been saved</source>
         <translation>Le tue impostazioni sono state salvate</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="89"/>
-        <location filename="../SettingsDialog.qml" line="119"/>
+        <location filename="../SettingsDialog.qml" line="90"/>
+        <location filename="../SettingsDialog.qml" line="120"/>
         <source>Download Path</source>
         <translation>Percorso Download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="91"/>
+        <location filename="../SettingsDialog.qml" line="92"/>
         <source>Download Location</source>
         <translation>Destinazione Download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="110"/>
+        <location filename="../SettingsDialog.qml" line="111"/>
         <location filename="../SettingsDialog.qml" line="320"/>
         <source>Playback Quality</source>
         <translation>Qualità Riproduzione</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="113"/>
+        <location filename="../SettingsDialog.qml" line="114"/>
         <location filename="../SettingsDialog.qml" line="338"/>
         <source>Download Quality</source>
         <translation>Qualità Download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="116"/>
+        <location filename="../SettingsDialog.qml" line="117"/>
         <location filename="../SettingsDialog.qml" line="356"/>
         <source>Start Downloads</source>
         <translation>Inizia Download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="122"/>
+        <location filename="../SettingsDialog.qml" line="123"/>
         <location filename="../SettingsDialog.qml" line="261"/>
         <location filename="../SettingsDialog.qml" line="394"/>
         <source>Safe Search</source>
         <translation>Ricerca Sicura</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="125"/>
+        <location filename="../SettingsDialog.qml" line="126"/>
         <location filename="../SettingsDialog.qml" line="412"/>
         <source>Screen Orientation</source>
         <translation>Orientamento Schermo</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="131"/>
+        <location filename="../SettingsDialog.qml" line="132"/>
         <location filename="../SettingsDialog.qml" line="285"/>
         <location filename="../SettingsDialog.qml" line="448"/>
         <source>Theme</source>
         <translation>Tema</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="134"/>
+        <location filename="../SettingsDialog.qml" line="135"/>
         <location filename="../SettingsDialog.qml" line="294"/>
         <location filename="../SettingsDialog.qml" line="466"/>
         <source>Language</source>
         <translation>Lingua</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="143"/>
+        <location filename="../SettingsDialog.qml" line="144"/>
         <source>Your saved searches have been cleared</source>
         <translation>Le tue ricerche salvate sono state cancellate</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="146"/>
+        <location filename="../SettingsDialog.qml" line="147"/>
         <source>Database error. Unable to clear searches</source>
         <translation>Errore database. Impossibile cancellare le ricerche</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="195"/>
+        <location filename="../SettingsDialog.qml" line="196"/>
         <source>Settings</source>
         <translation>Impostazioni</translation>
     </message>
@@ -1189,7 +1208,7 @@
 <context>
     <name>Widget</name>
     <message>
-        <location filename="../Widget.qml" line="271"/>
+        <location filename="../Widget.qml" line="287"/>
         <source>No videos found</source>
         <translation>Nessun video trovato</translation>
     </message>
@@ -1268,34 +1287,34 @@
         <translation>Hai effettuato l&apos;accesso a YouTube come &apos;</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="120"/>
-        <location filename="../../../youtube.cpp" line="226"/>
+        <location filename="../../../youtube.cpp" line="115"/>
+        <location filename="../../../youtube.cpp" line="221"/>
         <source>Error - Server repsonse is: </source>
         <translation>Errore - Il server ha risposto: </translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="170"/>
-        <location filename="../../../youtube.cpp" line="178"/>
+        <location filename="../../../youtube.cpp" line="165"/>
+        <location filename="../../../youtube.cpp" line="173"/>
         <source>Upload aborted</source>
         <translation>Caricamento interrotto</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="185"/>
+        <location filename="../../../youtube.cpp" line="180"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Caricamento interrotto. Tenetativo di ripresa...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="189"/>
+        <location filename="../../../youtube.cpp" line="184"/>
         <source>Upload failed</source>
         <translation>Caricamento fallito</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="195"/>
+        <location filename="../../../youtube.cpp" line="190"/>
         <source>Upload is completed</source>
         <translation>Caricamento completato</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="387"/>
+        <location filename="../../../youtube.cpp" line="382"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Errore: Impossibile recuperare il video</translation>
     </message>
@@ -1336,55 +1355,50 @@
         <translation>Video aggiunto alla playlist</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="159"/>
+        <location filename="../main.qml" line="160"/>
         <source>New playlist created</source>
         <translation>Nuova playlist creata</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="199"/>
+        <location filename="../main.qml" line="200"/>
         <source>Converting</source>
         <translation>In Conversione</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="208"/>
+        <location filename="../main.qml" line="209"/>
         <source>Conversion of &apos;</source>
         <translation>Conversione di &apos;</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="208"/>
+        <location filename="../main.qml" line="209"/>
         <source>&apos; failed</source>
         <translation>&apos; fallita</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="222"/>
-        <location filename="../main.qml" line="229"/>
-        <location filename="../main.qml" line="269"/>
+        <location filename="../main.qml" line="223"/>
+        <location filename="../main.qml" line="230"/>
+        <location filename="../main.qml" line="270"/>
         <source>Queued</source>
         <translation>In Coda</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="237"/>
+        <location filename="../main.qml" line="238"/>
         <source>Paused</source>
         <translation>In Pausa</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="414"/>
+        <location filename="../main.qml" line="415"/>
         <source>Most Recent</source>
         <translation>I Più Recenti</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="415"/>
+        <location filename="../main.qml" line="416"/>
         <source>Most Viewed</source>
         <translation>I Più Visti</translation>
     </message>
 </context>
 <context>
     <name>mainscripts</name>
-    <message>
-        <location filename="../scripts/mainscripts.js" line="19"/>
-        <source>Media Player</source>
-        <translation></translation>
-    </message>
     <message>
         <location filename="../scripts/mainscripts.js" line="119"/>
         <source>My Channel</source>
@@ -1464,11 +1478,6 @@
         <source>Automatic</source>
         <translation>Automatico</translation>
     </message>
-    <message>
-        <location filename="../scripts/settings.js" line="132"/>
-        <source>Media Player</source>
-        <translation></translation>
-    </message>
     <message>
         <location filename="../scripts/settings.js" line="133"/>
         <source>Date</source>
