@@ -27,7 +27,7 @@ public slots:
     QString getFacebookId() const { return facebookId; }
     void setFacebookToken(const QString &token);
 //    void setTwitterToken(const QString &token, const QString &secret);
-    void postToFacebook(const QString &videoId, const QString &message);
+    void postToFacebook(const QString &videoId, const QString &title, const QString &description, const QString &message);
 
 
 private slots:
